@@ -9,13 +9,11 @@
 
 #include <QHash>
 #include <QList>
+#include <QMap>
+#include <QString>
 
 #include "dynamicregexpcache_p.h"
 
-QT_BEGIN_NAMESPACE
-class QString;
-QT_END_NAMESPACE
-
 namespace KSyntaxHighlighting
 {
 class Definition;
@@ -46,6 +44,9 @@ public:
     // sorted map to have deterministic iteration order for e.g. definitionsForFileName
     QMap<QString, Definition> m_defs;
 
+    // map relating all names and alternative names, case insensitively to the correct definition.
+    QMap<QString, Definition> m_fullDefs;
+
     // this vector is sorted by translated sections/names
     QList<Definition> m_sortedDefs;
 
